==> aura-browser-5.27.9.tar.xz: aura-browser-5.27.9/app/org.kde.aura-browser.desktop.cmake <==
[Desktop Entry]
Name=Aura Browser
Name[ar]=متصفح أورا
Name[ast]=Restolador Aura
Name[ca]=Navegador Aura
Name[ca@valencia]=Navegador Aura
Name[cs]=Prohlížeč Aura
Name[de]=Aura Browser
Name[en_GB]=Aura Browser
Name[es]=Navegador Aura
Name[eu]=Aura Arakatzailea
Name[fi]=Aura-selain
Name[fr]=Navigateur Aura
Name[gl]=Navegador Aura
Name[ia]=Aura Browser (Navigator Aura)
Name[it]=Aura Browser
Name[ka]=Aura ბრაუზერი
Name[ko]=Aura 브라우저
Name[nl]=Aura-browser
Name[pl]=Przeglądarka Aura
Name[pt]=Navegador Aura
Name[pt_BR]=Navegador Aura
Name[ru]=Браузер Aura
Name[sl]=Brskalnik Aura
Name[sv]=Aura webbläsare
Name[tr]=Aura Tarayıcı
Name[uk]=Браузер Aura
Name[x-test]=xxAura Browserxx
MimeType=@DesktopMimeType@
Exec=@DesktopExec@
Icon=aura-browser
Type=Application
NoDisplay=@DesktopNoDisplay@
GenericName=Aura Browser
GenericName[ar]=متصفح أورا
GenericName[ast]=Restolador Aura
GenericName[ca]=Navegador Aura
GenericName[ca@valencia]=Navegador Aura
GenericName[cs]=Prohlížeč Aura
GenericName[de]=Aura Browser
GenericName[en_GB]=Aura Browser
GenericName[es]=Navegador Aura
GenericName[eu]=Aura arakatzailea
GenericName[fi]=Aura-selain
GenericName[fr]=Navigateur Aura
GenericName[gl]=Navegador Aura
GenericName[hi]=ओरा-ब्राउज़र
GenericName[hu]=Aura böngésző
GenericName[ia]=Aura Browser (Navigator Aura)
GenericName[it]=Aura Browser
GenericName[ka]=Aura ბრაუზერი
GenericName[ko]=Aura 브라우저
GenericName[nl]=Aura-browser
GenericName[nn]=Aura nettlesar
GenericName[pl]=Przeglądarka Aura
GenericName[pt]=Navegador Aura
GenericName[pt_BR]=Navegador Aura
GenericName[ro]=Navigator Aura
GenericName[ru]=Браузер Aura
GenericName[sk]=Prehliadač Aura
GenericName[sl]=Aura Browser
GenericName[sv]=Aura webbläsare
GenericName[tr]=Aura Tarayıcı
GenericName[uk]=Браузер Aura
GenericName[x-test]=xxAura Browserxx
GenericName[zh_CN]=光环浏览器
Categories=Qt;KDE;WebBrowser;Internet;
Keywords=program;software;Internet;
Keywords[ar]=برنامج;تطبيق;إنترنت;
Keywords[ast]=programa;software;Internet;aplicación;restolar;restolador;web
Keywords[ca]=programa;programari;Internet;
Keywords[ca@valencia]=programa;programari;Internet;
Keywords[cs]=program;software;Internet;
Keywords[de]=Browser;
Keywords[en_GB]=program;software;Internet;
Keywords[es]=programa;software;Internet;
Keywords[eu]=programa;softwarea;Internet;
Keywords[fi]=ohjelma;sovellus;internet;verkko;
Keywords[fr]=Internet;programme;logiciel;
Keywords[gl]=programa;aplicación;software;Internet;
Keywords[hi]=अनुप्रयोग;सॉफ्टवेयर;इंटरनेट;
Keywords[hu]=program;szoftver;Internet;
Keywords[ia]=program;software;Internet;
Keywords[it]=programma;software;Internet;
Keywords[ka]=პროგრამა;ინტერნეტი;
Keywords[ko]=program;software;Internet;프로그램;소프트웨어;인터넷;
Keywords[nl]=programma;software;internet;
Keywords[nn]=program;programvare;Internett;veven;
Keywords[pl]=program;oprogramowanie;Internet;
Keywords[pt]=programa;aplicação;Internet;
Keywords[pt_BR]=programa;software;Internet;
Keywords[ro]=program;software;Internet;
Keywords[ru]=program;software;Internet;приложение;программа;интернет
Keywords[sk]=program;softvér;Internet;
Keywords[sl]=program;software;Internet;
Keywords[sv]=program;programvara;Internet;
Keywords[tr]=program;yazılım;internet;
Keywords[uk]=program;software;Internet;програма;інтернет;
Keywords[x-test]=xxprogramxx;xxsoftwarexx;xxInternetxx;
Keywords[zh_CN]=program;software;Internet;

==> aura-browser-5.27.11.tar.xz: aura-browser-5.27.11/app/org.kde.aura-browser.desktop.cmake <==
[Desktop Entry]
Name=Aura Browser
Name[ar]=متصفح أورا
Name[ast]=Restolador Aura
Name[ca]=Navegador Aura
Name[ca@valencia]=Navegador Aura
Name[cs]=Prohlížeč Aura
Name[de]=Aura Browser
Name[en_GB]=Aura Browser
Name[eo]=Aura Browser
Name[es]=Navegador Aura
Name[eu]=Aura Arakatzailea
Name[fi]=Aura-selain
Name[fr]=Navigateur Aura
Name[gl]=Navegador Aura
Name[ia]=Aura Browser (Navigator Aura)
Name[it]=Aura Browser
Name[ka]=Aura ბრაუზერი
Name[ko]=Aura 브라우저
Name[nl]=Aura-browser
Name[pl]=Przeglądarka Aura
Name[pt]=Navegador Aura
Name[pt_BR]=Navegador Aura
Name[ru]=Браузер Aura
Name[sl]=Brskalnik Aura
Name[sv]=Aura webbläsare
Name[tr]=Aura Tarayıcı
Name[uk]=Браузер Aura
Name[x-test]=xxAura Browserxx
MimeType=@DesktopMimeType@
Exec=@DesktopExec@
Icon=aura-browser
Type=Application
NoDisplay=@DesktopNoDisplay@
GenericName=Aura Browser
GenericName[ar]=متصفح أورا
GenericName[ast]=Restolador Aura
GenericName[ca]=Navegador Aura
GenericName[ca@valencia]=Navegador Aura
GenericName[cs]=Prohlížeč Aura
GenericName[de]=Aura Browser
GenericName[en_GB]=Aura Browser
GenericName[eo]=Aura Browser
GenericName[es]=Navegador Aura
GenericName[eu]=Aura arakatzailea
GenericName[fi]=Aura-selain
GenericName[fr]=Navigateur Aura
GenericName[gl]=Navegador Aura
GenericName[hi]=ओरा-ब्राउज़र
GenericName[hu]=Aura böngésző
GenericName[ia]=Aura Browser (Navigator Aura)
GenericName[it]=Aura Browser
GenericName[ka]=Aura ბრაუზერი
GenericName[ko]=Aura 브라우저
GenericName[nl]=Aura-browser
GenericName[nn]=Aura nettlesar
GenericName[pl]=Przeglądarka Aura
GenericName[pt]=Navegador Aura
GenericName[pt_BR]=Navegador Aura
GenericName[ro]=Navigator Aura
GenericName[ru]=Браузер Aura
GenericName[sk]=Prehliadač Aura
GenericName[sl]=Aura Browser
GenericName[sv]=Aura webbläsare
GenericName[tr]=Aura Tarayıcı
GenericName[uk]=Браузер Aura
GenericName[x-test]=xxAura Browserxx
GenericName[zh_CN]=光环浏览器
Categories=Qt;KDE;WebBrowser;Internet;
Keywords=program;software;Internet;
Keywords[ar]=برنامج;تطبيق;إنترنت;
Keywords[ast]=programa;software;Internet;aplicación;restolar;restolador;web
Keywords[ca]=programa;programari;Internet;
Keywords[ca@valencia]=programa;programari;Internet;
Keywords[cs]=program;software;Internet;
Keywords[de]=Browser;
Keywords[en_GB]=program;software;Internet;
Keywords[eo]=programo;programaro;interreto;
Keywords[es]=programa;software;Internet;
Keywords[eu]=programa;softwarea;Internet;
Keywords[fi]=ohjelma;sovellus;internet;verkko;
Keywords[fr]=Internet;programme;logiciel;
Keywords[gl]=programa;aplicación;software;Internet;
Keywords[hi]=अनुप्रयोग;सॉफ्टवेयर;इंटरनेट;
Keywords[hu]=program;szoftver;Internet;
Keywords[ia]=program;software;Internet;
Keywords[it]=programma;software;Internet;
Keywords[ka]=პროგრამა;ინტერნეტი;
Keywords[ko]=program;software;Internet;프로그램;소프트웨어;인터넷;
Keywords[nl]=programma;software;internet;
Keywords[nn]=program;programvare;Internett;veven;
Keywords[pl]=program;oprogramowanie;Internet;
Keywords[pt]=programa;aplicação;Internet;
Keywords[pt_BR]=programa;software;Internet;
Keywords[ro]=program;software;Internet;
Keywords[ru]=program;software;Internet;приложение;программа;интернет
Keywords[sk]=program;softvér;Internet;
Keywords[sl]=program;software;Internet;
Keywords[sv]=program;programvara;Internet;
Keywords[tr]=program;yazılım;internet;
Keywords[uk]=program;software;Internet;програма;інтернет;
Keywords[x-test]=xxprogramxx;xxsoftwarexx;xxInternetxx;
Keywords[zh_CN]=program;software;Internet;程序;软件;互联网;上网;网页;网站;浏览;chengxu;ruanjian;hulianwang;shangwang;wangye;wangzhan;liulan;
